@@ -11,9 +11,9 @@ DEFAULT_IGNORED_FILES = (
     ".idea",
     ".git",
     "venv",
-    "requirements.txt",
 )
 AVAILABLE_PYTHON_VERSIONS = (
+    "python39-preview",
     "python38",
     "python37",
 )
@@ -31,4 +31,4 @@ HANDLERS = {
     "manage": "handlers.manage.manage",
     "raw": None,
 }
-DEFAULT_CONFIG_FILENAME = "yappa.yaml"
+MAX_DIRECT_ARCHIVE_SIZE = 4170000
