@@ -1,10 +1,5 @@
 import yaml
 
-try:
-    from yaml import CLoader as Loader, CDumper as Dumper
-except ImportError:
-    from yaml import Loader, Dumper
-
 from yappa.settings import HANDLERS
 
 MIN_MEMORY, MAX_MEMORY = 134217728, 2147483648
@@ -13,7 +8,7 @@ SIZE_SUFFIXES = {
     'kb': 1024,
     'mb': 1024 * 1024,
     'gb': 1024 * 1024 * 1024,
-}
+    }
 
 
 def convert_size_to_bytes(size_str):
@@ -37,7 +32,7 @@ def get_yc_entrypoint(application_type, raw_entrypoint):
             f"Sorry, supported app types are: "
             f"{','.join(HANDLERS.keys())}. "
             f"Got {application_type}"
-        )
+            )
     return entrypoint
 
 
